package
Version:
v0.0.0-...-e0e0083
Opens a new window with list of versions in this module.
Published: Apr 13, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Template struct {
Key string `json:"key"`
Name string `json:"name"`
Description string `json:"description"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.